@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: config.c,v 1.46 2005/09/25 16:23:43 hany Exp $
+ * $Id: config.c,v 1.48 2007/04/01 16:36:21 hany Exp $
  */
 
 #include <config.h>
@@ -47,6 +47,10 @@ char *rpm2html_ftp		= NULL;
 char *rpm2html_ftpsrc		= NULL;
 char *rpm2html_host		= NULL;
 int   rpm2html_build_tree	= 0;
+int   rpm2html_cve_linking      = 1;
+#ifdef HAVE_LIBTEMPLATE
+char *rpm2html_html_template	= "rpm2html.tpl";
+#endif
 int   rpm2html_dump_html	= 1;
 int   rpm2html_dump_rdf		= 0;
 int   rpm2html_dump_rdf_resources= 0;
@@ -336,6 +340,10 @@ void addConfigEntry(char *rpmdir, char *name, char *value) {
 		printf("Config file : %s global entry ignored,\n", name);
 		printf("\tuse \"html=true\" or \"html=false\"\n");
 	    }
+        #ifdef HAVE_LIBTEMPLATE
+	} else if (!strcasecmp(name, "html_template")) {
+	    rpm2html_html_template = xmlStrdup(value);
+        #endif
 	} else if (!strcasecmp(name, "protectemails")) {
 	    if ((!strcasecmp(value, "true")) ||
 	        (!strcasecmp(value, "yes"))) {
@@ -347,6 +355,17 @@ void addConfigEntry(char *rpmdir, char *name, char *value) {
 		printf("Config file : %s global entry ignored,\n", name);
 		printf("\tuse \"protectemails=true\" or \"protectemails=false\"\n");
 	    }
+	} else if (!strcasecmp(name, "cve_linking")) {
+	    if ((!strcasecmp(value, "true")) ||
+	        (!strcasecmp(value, "yes"))) {
+	        rpm2html_cve_linking = 1;
+	    } else if ((!strcasecmp(value, "false")) ||
+	        (!strcasecmp(value, "no"))) {
+	        rpm2html_cve_linking = 0;
+	    } else {
+		printf("Config file : %s global entry ignored,\n", name);
+		printf("\tuse \"cve_linking=true\" or \"cve_linking=false\"\n");
+	    }
 	} else if (!strcasecmp(name, "header")) {
 	    addHeader(value);
         } else {
@@ -731,5 +750,8 @@ void reinitialize(void) {
     rpmdataCleanup();
     htmlCleanup();
     rpmopenCleanup();
+    #ifdef HAVE_LIBTEMPLATE
+    destroyTemplateEngine();
+    #endif
 }
 
