@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * $Id: rpm2html.h,v 1.71 2005/09/25 16:29:05 hany Exp $
+ * $Id: rpm2html.h,v 1.74 2007/04/01 16:36:21 hany Exp $
  */
 
 #ifndef __RPM2HTML_H__
@@ -16,7 +16,7 @@
  * General setup default values overriden by config file.
  */
 #define RPM2HTML_NAME	"rpm2html"
-#define RPM2HTML_VER	"1.9.2"
+#define RPM2HTML_VER	"1.9.3"
 #define RPM2HTML_URL    "http://rpmfind.net/linux/rpm2html/"
 #define RPM2HTML_MAINT	"Daniel Veillard"
 #define RPM2HTML_MAIL 	"daniel@veillard.com"
@@ -71,10 +71,14 @@ extern char *rpm2html_host;	/* OK */
 extern int   rpm2html_dump_rdf;
 extern int   rpm2html_dump_rdf_resources;
 extern int   rpm2html_dump_html;
+#ifdef HAVE_LIBTEMPLATE
+extern char *rpm2html_html_template;
+#endif
 extern char *rpm2html_rdf_dir;	/* OK */
 extern char *rpm2html_rdf_resources_dir;	/* OK */
 extern int   rpm2html_rdf_count_limit;
 extern int   rpm2html_build_tree;
+extern int   rpm2html_cve_linking;
 extern int   rpm2html_no_sql;
 extern int   rpm2html_protect_emails;
 
